@@ -36,7 +36,7 @@ class ParameterView(web.View):
 
     def query_parameter(
             self,
-            name_in_request: str,
+            name_in_query_string: str,
             *,
             required: bool = False,
             ignore_errors: bool = False,
@@ -57,6 +57,62 @@ class ParameterView(web.View):
             choices_are_case_insensitive: bool = False,
             choices_mapping: Optional[Mapping] = None,
     ) -> validated_query_parameter:
+        """
+        Read, validate and convert parameter located in URL query string.
+
+        This method returns validated value, converted to specified type (see
+        flags `is_int`, `is_date`, etc.). The default value type is `str`, you
+        can omit specifying `is_string=True` in this case.
+
+        At most one of following flags should be equal to `True`: `is_int`,
+        `is_decimal`, `is_date`, `is_bool`.
+
+        :param name_in_query_string: name of parameter in target
+            location (path, URL query string, etc.).
+        :param required: flag indicating that parameter must be present in
+            target location. Optional parameters should have `required=False`
+            set. If required parameter is missing in target location, HTTP 400
+            is raised by default (this behaviour can be overridden in
+            `validation_error_handler` method of this base class).
+        :param ignore_errors: return default value for parameter instead
+            of returning HTTP 400 to client.
+        :param default: value to be returned if a non-required parameter's
+            value is missing or if `ignore_errors=True` flag is set.
+        :param is_array: flag indicating that parameter value should be
+            treated as an array of values. The return type in this case is
+            tuple of values. Type of values is specified by `is_string`,
+            `is_int`, `is_decimal`, `is_date`, `is_bool` flags, which
+            defaults to string. Nested arrays are not supported.
+        :param is_string: the default return type of this method. No type
+            conversion takes place in this case.
+        :param is_int: flag indicating that value should be treated-as and
+            converted to an `int`.
+        :param is_decimal: flag indicating that value should be treated as
+            float. A `Decimal` instance is returned in this case.
+        :param is_date: flag indicating that date-formatted string is
+            expected. The default format is "%Y-%m-%d"; can be overridden
+            in `date_format` attribute of this base class. Returned value
+            also has a timezone which defaults to UTC and can be overridden in
+            `tz` attribute of this base class.
+        :param is_bool: flag that indicates that parameter value should be
+            treated as `bool`. Acceptable values are: 1/true/TrUe/truE or
+            0/FALSE/False/false.
+        :param min_length: minimum allowed length for string parameters.
+        :param max_length: maximum allowed length for string parameters.
+        :param min_value: minimum allowed value for numeric parameters.
+        :param max_value: maximum allowed value for numeric parameters.
+        :param min_items: minimum allowed array length if parameter is
+            an array.
+        :param max_items: maximum allowed array length if parameter is
+            an array.
+        :param choices: works like an enum: input parameter value is validated
+            against items in specified iterable. Overrides following kwargs:
+            `min_length`, `max_length`, `min_value`, `max_value`.
+        :param choices_are_case_insensitive: not implemented yet.
+        :param choices_mapping: if value is validated against `choices`,
+            return appropriate value according to provided mapping (usually
+            a `dict`).
+        """
         valid_config = (is_int + is_decimal + is_date + is_bool) <= 1
         if not valid_config:
             raise ConfigError(
@@ -68,17 +124,17 @@ class ParameterView(web.View):
             is_string = False
 
         raw_value: Union[None, str] = self.request.rel_url.query.get(
-            name_in_request,
+            name_in_query_string,
         )
         if is_array:
             raw_value: Optional[list[str]] = self.request.query.getall(
-                name_in_request, None,
+                name_in_query_string, None,
             )
 
         try:
             return self._parse_parameter(
                 raw_value,
-                name_in_request,
+                name_in_query_string,
                 required=required,
                 default=default,
                 is_array=is_array,
@@ -117,6 +173,39 @@ class ParameterView(web.View):
             choices: Optional[Iterable] = None,
             choices_mapping: Optional[Mapping] = None,
     ) -> Union[str, int, None]:
+        """
+        Read, validate and convert parameter located in URL path.
+
+        This method returns validated value, converted to specified type (see
+        `is_int` flag). The default value type is `str`, you can omit
+        specifying `is_string=True` in this case.
+
+        :param name_in_path:  name of parameter in target
+            location (path, URL query string, etc.).
+        :param required: flag indicating that parameter must be present in
+            target location. Optional parameters should have `required=False`
+            set. If required parameter is missing in target location, HTTP 400
+            is raised by default (this behaviour can be overridden in
+            `validation_error_handler` method of this base class).
+        :param ignore_errors: return default value for parameter instead
+            of returning HTTP 400 to client.
+        :param default: value to be returned if a non-required parameter's
+            value is missing or if `ignore_errors=True` flag is set.
+        :param is_string: the default return type of this method. No type
+            conversion takes place in this case.
+        :param is_int: flag indicating that value should be treated-as and
+            converted to an `int`.
+        :param min_length: minimum allowed length for string parameters.
+        :param max_length: maximum allowed length for string parameters.
+        :param min_value: minimum allowed value for numeric parameters.
+        :param max_value: maximum allowed value for numeric parameters.
+        :param choices: works like an enum: input parameter value is validated
+            against items in specified iterable. Overrides following kwargs:
+            `min_length`, `max_length`, `min_value`, `max_value`.
+        :param choices_mapping: if value is validated against `choices`,
+            return appropriate value according to provided mapping (usually
+            a `dict`).
+        """
         if is_int:
             is_string = False
 
